body { margin: 20px 0 0; background: #fff; font: .74em "Trebuchet MS", Arial, Sans-Serif; color: #444; }
	h1 { font-size: 3em; font-weight: normal; float: left; }
	h1 a { text-decoration: none; }
	h2 { font-size: 2em; color: #FFF2B3; font-weight: normal; margin: 0 0 .8em; }
	p  { margin: 0 0 2em 0; line-height: 1.8em; }
	a { color: #9D2900; }
	a:hover { color: #A0000E; text-decoration: none; }
	img { border: 0; }
	.red { color: #9D2900; }
	
.wrap { width: 900px; margin: auto auto; }
	
#header { width: 900px; height: 75px; margin: 0 auto; }
	#logo { float: center; width: 250px; position: absolute; top: 12px; height: 200px; }
	#menu  { float: right; padding: 6px 0 0 0; list-style: none; }
		#menu li { display: inline; }
		#menu a { display: block; float: left; margin-left: 30px; padding: 7px; text-decoration: none; font-size: 13px; color: #000000; }
		#menu a:hover { color: #000; border-bottom: 2px solid #ccc; }

#cardinal {
    display: block; margin-left: 0px; margin-right: 0; width: 5px;
}

#my-div{
	margin: 0 auto;
	width: 80%;
	height: 50%;
	resize :both;
	margin-left: auto;
	margin-right: auto;
}

.img {                        /* text style on 825 banner*/
    position: relative;
    margin-left: auto;
    margin-right: auto;
}

.img prim {                      /* prim (Login)text style on 825 banner*/
  position: absolute;
  top: 22%;
  left: 10%;
  font-size: 150%; 
  color: darkorange
}

.img sec {                     /* sec (Login to access 825 resources)text style on 825 banner*/
  position: absolute;
  bottom: 30%;
  left: 10%;
  color: darkblue
}

.img second {                     /* sec (Login to access 825 resources)text style on 825 banner*/
  position: absolute;
  bottom: -50;
  left: 2%;
  word-break: break-all;
  color: darkblue
}

#footer { clear: both; width: 900px; margin: 0 auto; padding: 15px; border-top: 1px solid #e0e0e0;  }	
	#footer .right { float: right; margin: 0 55px 0 0; }
	#footer a { color: #808080; font-weight: bold; }

#message {
	background:#FAE79A url('../warning.jpg') no-repeat 10px 10px;
	border-bottom:2px solid #F4CA21;
	border-top:2px solid #F4CA21;
	clear:both;
	color:#7A5511;
	width:400px;
	margin:0 auto;
	padding:12px 10px 12px 39px;
}
