/* Style for Asteroids.js
 * Copyright (c) 2010 James Socol <me@jamessocol.com>
 * See LICENSE.txt for license.
 */

body {
    background-color: #000;
    color: #fff;
    font-family: "Calibri", "System", monospace;
    font-size: 14px;
}

div#asteroids {
    margin: 50px auto;
    width: 640px;
    border: 1px solid #fff;
    padding: 5px;
}

div#asteroids > * {
    color: #fff;
}

div#asteroids > div {
    font-family: "System", monospace;
    font-size: 11px;
    padding-bottom: 5px;
}

div#asteroids > div > span {
    float: right;
    padding-left: 20px;
}

div#asteroids > div > span2 {
    float: left;
    padding-left: 20px;
}

div#instructions {
    width: 640px;
    margin: 20px auto;
}

#tbtns {
    background-color: #000;
	height: 80px;
	//padding: 20px;
	
	font-size: 36px;
}

.tbtn {
	margin: 8px;
    font-family: Arial, Helvetica, sans-serif;
    font-size: 28px;
}

h1 {
    font-size: 18px;
}

h2 {
    font-size: 16px;
}
